@@ -261,35 +261,6 @@ gs_plugin_app_source_enable (GsPlugin *plugin,
 	return TRUE;
 }
 
-static gboolean
-gs_plugin_repo_enable (GsPlugin *plugin,
-                       GsApp *repo,
-                       GCancellable *cancellable,
-                       GError **error)
-{
-	GsPluginData *priv = gs_plugin_get_data (plugin);
-	ProgressData data;
-	g_autoptr(PkResults) results = NULL;
-
-	data.app = repo;
-	data.plugin = plugin;
-	data.ptask = NULL;
-
-	/* do sync call */
-	gs_plugin_status_update (plugin, repo, GS_PLUGIN_STATUS_WAITING);
-	results = pk_client_repo_enable (PK_CLIENT (priv->task),
-					 gs_app_get_id (repo),
-					 TRUE,
-					 cancellable,
-					 gs_plugin_packagekit_progress_cb, &data,
-					 error);
-	if (!gs_plugin_packagekit_results_valid (results, error)) {
-		gs_utils_error_add_unique_id (error, repo);
-		return FALSE;
-	}
-	return TRUE;
-}
-
 gboolean
 gs_plugin_app_install (GsPlugin *plugin,
 		       GsApp *app,
@@ -316,13 +287,7 @@ gs_plugin_app_install (GsPlugin *plugin,
 		       gs_plugin_get_name (plugin)) != 0)
 		return TRUE;
 
-	/* enable repo */
-	if (gs_app_get_kind (app) == AS_APP_KIND_SOURCE) {
-		return gs_plugin_repo_enable (plugin, app,
-		                              cancellable, error);
-	}
-
-	/* enable the repo where the unavailable app is coming from */
+	/* we enable the repo */
 	if (gs_app_get_state (app) == AS_APP_STATE_UNAVAILABLE) {
 
 		/* get everything up front we need */
@@ -673,7 +638,6 @@ gs_plugin_add_search_what_provides (GsPlugin *plugin,
 	gs_plugin_status_update (plugin, NULL, GS_PLUGIN_STATUS_WAITING);
 	filter = pk_bitfield_from_enums (PK_FILTER_ENUM_NEWEST,
 					 PK_FILTER_ENUM_ARCH,
-					 PK_FILTER_ENUM_NOT_INSTALLED,
 					 -1);
 	results = pk_client_what_provides (PK_CLIENT (priv->task),
 	                                   filter,
