@@ -109,7 +109,7 @@ static void
 gs_plugin_steam_find_next_sync_point (guint8 *data, gsize data_len, guint *idx)
 {
 	guint i;
-	for (i = *idx; i < data_len - 9; i++) {
+	for (i = *idx; i + 9 < data_len; i++) {
 		if (memcmp (&data[i], "\0\x02\0common\0", 8) == 0) {
 			*idx = i - 1;
 			return;
@@ -389,8 +389,6 @@ gs_plugin_steam_download_icon (GsPlugin *plugin,
 			return FALSE;
 		}
 	} else {
-		if (!gs_mkdir_parent (cache_fn, error))
-			return FALSE;
 		if (!gs_plugin_download_file (plugin,
 					      NULL, /* GsApp */
 					      uri,
