@@ -276,8 +276,7 @@ gs_app_row_refresh_button (GsAppRow *app_row, gboolean missing_search_result)
 			gtk_widget_set_sensitive (priv->button, FALSE);
 			break;
 		default:
-			gtk_widget_set_sensitive (priv->button,
-						  gs_app_get_allow_cancel (priv->app));
+			gtk_widget_set_sensitive (priv->button, TRUE);
 			break;
 		}
 	}
@@ -699,7 +698,6 @@ gs_app_row_init (GsAppRow *app_row)
 	gtk_widget_init_template (GTK_WIDGET (app_row));
 	gs_star_widget_set_icon_size (GS_STAR_WIDGET (priv->star), 12);
 
-	priv->colorful = TRUE;
 	priv->settings = g_settings_new ("org.gnome.software");
 
 	g_signal_connect (priv->button, "clicked",
