@@ -52,8 +52,6 @@ void		 gs_app_row_set_show_sandbox		(GsAppRow	*app_row,
 							 gboolean	 show_sandbox);
 void		 gs_app_row_set_show_source		(GsAppRow	*app_row,
 							 gboolean	 show_source);
-void		 gs_app_row_set_show_codec		(GsAppRow	*app_row,
-							 gboolean	 show_codec);
 void		 gs_app_row_set_show_update		(GsAppRow	*app_row,
 							 gboolean	 show_update);
 void		 gs_app_row_set_selectable 		(GsAppRow	*app_row,
