@@ -58,6 +58,7 @@ typedef struct
 	GtkWidget		*bin_featured;
 	GtkWidget		*box_overview;
 	GtkWidget		*box_popular;
+	GtkWidget		*box_popular_rotating;
 	GtkWidget		*box_recent;
 	GtkWidget		*featured_heading;
 	GtkWidget		*category_heading;
@@ -167,13 +168,21 @@ gs_overview_page_get_popular_cb (GObject *source_object,
 
 	/* get popular apps */
 	list = gs_plugin_loader_job_process_finish (plugin_loader, res, &error);
-	gtk_widget_set_visible (priv->box_popular, list != NULL);
-	gtk_widget_set_visible (priv->popular_heading, list != NULL);
 	if (list == NULL) {
 		if (!g_error_matches (error, GS_PLUGIN_ERROR, GS_PLUGIN_ERROR_CANCELLED))
 			g_warning ("failed to get popular apps: %s", error->message);
 		goto out;
 	}
+
+	/* not enough to show */
+	if (gs_app_list_length (list) < N_TILES) {
+		g_warning ("Only %u apps for popular list, hiding",
+		           gs_app_list_length (list));
+		gtk_widget_set_visible (priv->box_popular, FALSE);
+		gtk_widget_set_visible (priv->popular_heading, FALSE);
+		goto out;
+	}
+
 	/* Don't show apps from the category that's currently featured as the category of the day */
 	gs_app_list_filter (list, filter_category, priv->category_of_day);
 	gs_app_list_randomize (list);
@@ -187,6 +196,8 @@ gs_overview_page_get_popular_cb (GObject *source_object,
 			  G_CALLBACK (app_tile_clicked), self);
 		gtk_container_add (GTK_CONTAINER (priv->box_popular), tile);
 	}
+	gtk_widget_set_visible (priv->box_popular, TRUE);
+	gtk_widget_set_visible (priv->popular_heading, TRUE);
 
 	priv->empty = FALSE;
 
@@ -326,14 +337,14 @@ gs_overview_page_get_category_apps_cb (GObject *source_object,
 	g_signal_connect (button, "clicked",
 			  G_CALLBACK (gs_overview_page_category_more_cb), self);
 	gtk_container_add (GTK_CONTAINER (headerbox), button);
-	gtk_container_add (GTK_CONTAINER (priv->box_overview), headerbox);
+	gtk_container_add (GTK_CONTAINER (priv->box_popular_rotating), headerbox);
 
 	/* add hiding box */
 	box = gs_hiding_box_new ();
 	gs_hiding_box_set_spacing (GS_HIDING_BOX (box), 14);
 	gtk_widget_set_visible (box, TRUE);
 	gtk_widget_set_valign (box, GTK_ALIGN_START);
-	gtk_container_add (GTK_CONTAINER (priv->box_overview), box);
+	gtk_container_add (GTK_CONTAINER (priv->box_popular_rotating), box);
 
 	/* add all the apps */
 	for (i = 0; i < gs_app_list_length (list) && i < N_TILES; i++) {
@@ -602,6 +613,9 @@ gs_overview_page_load (GsOverviewPage *self)
 		g_autoptr(GPtrArray) cats_random = NULL;
 		cats_random = gs_overview_page_get_random_categories ();
 
+		/* remove existing widgets, if any */
+		gs_container_remove_all (GTK_CONTAINER (priv->box_popular_rotating));
+
 		/* load all the categories */
 		for (i = 0; i < cats_random->len && i < MAX_CATS; i++) {
 			LoadData *load_data;
@@ -852,7 +866,13 @@ gs_overview_page_refresh_proprietary (GsOverviewPage *self)
 						uri, _("Find out more…"));
 		}
 		gtk_label_set_markup (GTK_LABEL (priv->label_proprietary), str->str);
+#if 0
 		gtk_widget_set_visible (priv->infobar_proprietary, TRUE);
+#else
+		/* temporarily disabled until we've updated the text and synced
+		 * up with what gnome-initial-setup is doing */
+		gtk_widget_set_visible (priv->infobar_proprietary, FALSE);
+#endif
 	} else {
 		gtk_widget_set_visible (priv->infobar_proprietary, FALSE);
 	}
@@ -902,9 +922,10 @@ gs_overview_page_setup (GsPage *page,
 		gtk_container_add (GTK_CONTAINER (priv->box_popular), tile);
 	}
 
-	/* hide unless there are enough apps */
-	gtk_widget_set_visible (priv->box_recent, FALSE);
-	gtk_widget_set_visible (priv->recent_heading, FALSE);
+	for (i = 0; i < N_TILES; i++) {
+		tile = gs_popular_tile_new (NULL);
+		gtk_container_add (GTK_CONTAINER (priv->box_recent), tile);
+	}
 
 	/* handle category expander */
 	g_signal_connect (priv->categories_expander_button_down, "clicked",
@@ -997,6 +1018,7 @@ gs_overview_page_class_init (GsOverviewPageClass *klass)
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, bin_featured);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_overview);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_popular);
+	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_popular_rotating);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, box_recent);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, category_heading);
 	gtk_widget_class_bind_template_child_private (widget_class, GsOverviewPage, featured_heading);
